You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@tuscany.apache.org by ro...@apache.org on 2007/08/26 10:44:53 UTC

svn commit: r569777 [3/3] - in /incubator/tuscany/cpp: sca/runtime/core/src/tuscany/sca/model/ sca/runtime/core/src/tuscany/sca/util/ sca/runtime/extensions/python/src/tuscany/sca/python/ sca/runtime/extensions/rest/reference/curl/src/tuscany/sca/rest/...

Modified: incubator/tuscany/cpp/sdo/runtime/core/src/commonj/sdo/Type.cpp
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sdo/runtime/core/src/commonj/sdo/Type.cpp?rev=569777&r1=569776&r2=569777&view=diff
==============================================================================
--- incubator/tuscany/cpp/sdo/runtime/core/src/commonj/sdo/Type.cpp (original)
+++ incubator/tuscany/cpp/sdo/runtime/core/src/commonj/sdo/Type.cpp Sun Aug 26 01:44:46 2007
@@ -29,8 +29,6 @@
      {
      }
 
-     const SDOString Type::SDOTypeNamespaceURI = "commonj.sdo";
-
 };
 };
 // end - namespace sdo

Modified: incubator/tuscany/cpp/sdo/runtime/core/src/commonj/sdo/Type.h
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sdo/runtime/core/src/commonj/sdo/Type.h?rev=569777&r1=569776&r2=569777&view=diff
==============================================================================
--- incubator/tuscany/cpp/sdo/runtime/core/src/commonj/sdo/Type.h (original)
+++ incubator/tuscany/cpp/sdo/runtime/core/src/commonj/sdo/Type.h Sun Aug 26 01:44:46 2007
@@ -77,8 +77,6 @@
     DataObjectType,
     ChangeSummaryType,
     TextType,
-    OpenDataObjectType,
-    num_types
    };
 
     virtual SDO_API ~Type();
@@ -222,8 +220,6 @@
      */
 
     virtual SDO_API bool equals(const Type& tother) const = 0;
-
-    static SDO_API const SDOString SDOTypeNamespaceURI;
 };
 
 };

Modified: incubator/tuscany/cpp/sdo/runtime/core/src/commonj/sdo/TypeImpl.cpp
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sdo/runtime/core/src/commonj/sdo/TypeImpl.cpp?rev=569777&r1=569776&r2=569777&view=diff
==============================================================================
--- incubator/tuscany/cpp/sdo/runtime/core/src/commonj/sdo/TypeImpl.cpp (original)
+++ incubator/tuscany/cpp/sdo/runtime/core/src/commonj/sdo/TypeImpl.cpp Sun Aug 26 01:44:46 2007
@@ -35,34 +35,70 @@
 using namespace std;
 
 #include "commonj/sdo/SDORuntimeException.h"
+#include "commonj/sdo/SDOUtils.h"
 
 namespace commonj{
 namespace sdo{
 
  
+      using internal::SDOUtils;
 
-    char* TypeImpl::types[num_types] = {
-    "Other Types",
-    "BigDecimal",
-    "BigInteger",
-    "Boolean"   , 
-    "Byte",
-    "Bytes",
-    "Character",
-    "Date"      ,
-    "Double"    ,
-    "Float"     ,
-    "Integer"   ,
-    "Long"      ,
-    "Short"     ,
-    "String"    ,
-    "URI"        ,
-    "DataObject",
-    "ChangeSummary",
-    "Text",
-    "OpenDataObject"
-     };
+    Type::Types
+    toTypeEnum(const SDOString& typeName)
+    {
+      switch (typeName.size()) {
+      case 3:
+        if (typeName == "URI") return Type::UriType;
+        if (typeName == "Int") return Type::IntType;
+        break;
+      case 4:
+        if (typeName == "Byte") return Type::ByteType;
+        if (typeName == "Date") return Type::DateType;
+        if (typeName == "Long") return Type::LongType;
+        if (typeName == "Text") return Type::TextType;
+        break;
+      case 5:
+        if (typeName == "Bytes") return Type::BytesType;
+        if (typeName == "Float") return Type::FloatType;
+        if (typeName == "Short") return Type::ShortType;
+        break;
+      case 6:
+        if (typeName == "Double") return Type::DoubleType;
+        if (typeName == "String") return Type::StringType;
+        break;
+      case 7:
+        if (typeName == "Boolean") return Type::BooleanType;
+        if (typeName == "Decimal") return Type::BigDecimalType;
+        if (typeName == "Integer") return Type::BigIntegerType;
+        break;
+      case 9:
+        if (typeName == "Character") return Type::CharacterType;
+        break;
+      case 10:
+        if (typeName == "DataObject") return Type::DataObjectType;
+        break;
+      case 13:
+        if (typeName == "ChangeSummary") return Type::ChangeSummaryType;
+        break;
+      case 14:
+        if (typeName == "OpenDataObject") return Type::DataObjectType;
+        break;
+      };
+      return Type::OtherTypes;
+    }
 
+    bool
+    enumIsPrimitive(Type::Types enumValue)
+    {
+      switch (enumValue) {
+      case Type::ChangeSummaryType:
+      case Type::DataObjectType:
+      case Type::OtherTypes:
+      case Type::TextType:
+        return false;
+      };
+      return true;
+    }
 
     ///////////////////////////////////////////////////////////////////////////
     //
@@ -165,20 +201,11 @@
         typeURI = new char[strlen(uri)+1];
         strcpy(typeURI,uri);
 
-        if (!strcmp(uri,Type::SDOTypeNamespaceURI.c_str()))  {
-            for (int i = 0; i < num_types ; i++) {
-                if (!strcmp(inname,types[i])) {
-                    typeEnum = (Types)i;
-                    if (i <= UriType) isPrimitive = true;
-                    // Note - you could create Text, but it would
-                    // not be recognised as primitive.
-                    return;
-                }
-            }
-        }
-
-        // All other types are data object types - for now 
         typeEnum = DataObjectType;
+        if (!strcmp(uri,SDOUtils::sdoURI))  {
+          typeEnum = toTypeEnum(inname);
+        }
+        isPrimitive = enumIsPrimitive(typeEnum);
      }
 
 
@@ -1589,7 +1616,7 @@
         case ChangeSummaryType:
         default:
             {
-            string msg("Cannot set Integer on object of type:");
+            string msg("Cannot set Int on object of type:");
             msg += getName();
             throw SDOInvalidConversionException(TUSCANY_SDO_EINFO,
                                                 msg.c_str());
@@ -3283,7 +3310,7 @@
     }
 
   */
-    const long TypeImpl::convertToInteger(void* value, unsigned int len) const
+    const long TypeImpl::convertToInt(void* value, unsigned int len) const
     {
 #if ! defined(WIN32)  && ! defined (_WINDOWS)
             char* tmp = new char[len+1];
@@ -3381,7 +3408,7 @@
         }
     }
 
-   const long TypeImpl::convertToInteger(const SDOValue& sdoValue) const
+   const long TypeImpl::convertToInt(const SDOValue& sdoValue) const
    {
       switch (typeEnum) 
       {
@@ -3399,7 +3426,7 @@
          case StringType:    
          case UriType:
          case BytesType:
-            return sdoValue.getInteger();
+            return sdoValue.getInt();
 
          case OtherTypes:
          case DataObjectType:

Modified: incubator/tuscany/cpp/sdo/runtime/core/src/commonj/sdo/TypeImpl.h
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sdo/runtime/core/src/commonj/sdo/TypeImpl.h?rev=569777&r1=569776&r2=569777&view=diff
==============================================================================
--- incubator/tuscany/cpp/sdo/runtime/core/src/commonj/sdo/TypeImpl.h (original)
+++ incubator/tuscany/cpp/sdo/runtime/core/src/commonj/sdo/TypeImpl.h Sun Aug 26 01:44:46 2007
@@ -113,8 +113,8 @@
      const wchar_t        convertToCharacter(const SDOValue& sdoValue) const; 
      const short          convertToShort(     void* value ,unsigned int len) const; 
      const short          convertToShort(const SDOValue& sdoValue) const; 
-     const long           convertToInteger(   void* value ,unsigned int len) const; 
-     const long           convertToInteger(const SDOValue& sdoValue) const; 
+     const long           convertToInt(   void* value ,unsigned int len) const; 
+     const long           convertToInt(const SDOValue& sdoValue) const; 
      const int64_t        convertToLong(      void* value ,unsigned int len) const; 
      const int64_t        convertToLong(const SDOValue& sdoValue) const; 
      const float          convertToFloat(     void* value ,unsigned int len) const; 
@@ -305,7 +305,6 @@
     char* name;
     char* typeURI;
 
-
     bool isPrimitive;
     bool isSequenced;
     bool isOpen;
@@ -319,23 +318,17 @@
 
     Types typeEnum;
     
-    static char* types[num_types];
-
     // alias support
-
     std::vector<char*> aliases;
 
-
     std::vector<PropertyImplPtr> props;
 
-
     // type inheritance
     TypeImpl* baseType;
     bool brestriction; /* if this is a restriction of the base type
                             rather than an extension.*/
     // says how many of the props are really in this data object type.
     unsigned int localPropsSize;
-
 };
 
 };

Modified: incubator/tuscany/cpp/sdo/runtime/core/src/commonj/sdo/XSDHelperImpl.cpp
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sdo/runtime/core/src/commonj/sdo/XSDHelperImpl.cpp?rev=569777&r1=569776&r2=569777&view=diff
==============================================================================
--- incubator/tuscany/cpp/sdo/runtime/core/src/commonj/sdo/XSDHelperImpl.cpp (original)
+++ incubator/tuscany/cpp/sdo/runtime/core/src/commonj/sdo/XSDHelperImpl.cpp Sun Aug 26 01:44:46 2007
@@ -40,6 +40,7 @@
 #include "commonj/sdo/DASProperty.h"
 #include "commonj/sdo/Logging.h"
 #include "commonj/sdo/Type.h"
+#include "commonj/sdo/SDOUtils.h"
 
 namespace commonj
 {
@@ -53,6 +54,7 @@
         using internal::TypeDefinitionsImpl;
         using internal::XmlDasPropertyDefs;
         using internal::XMLDAS_TypeDefs;
+        using internal::SDOUtils;
     
         /**  XSDHelperImpl
          *
@@ -155,7 +157,7 @@
                      j++)
                 {
                     if (!(*j)->getType().isDataType()
-                        && strcmp((*j)->getType().getURI(),Type::SDOTypeNamespaceURI.c_str()))
+                        && strcmp((*j)->getType().getURI(),SDOUtils::sdoURI))
                     {
                         // recurse the tree..
                        newSubstitute((*j)->getType().getName(), prop);
@@ -447,7 +449,7 @@
                     }
                         
                     // Do not add DASValue to ChangeSummary
-                    if (!(prop.typeUri.equals(Type::SDOTypeNamespaceURI.c_str())
+                    if (!(prop.typeUri.equals(SDOUtils::sdoURI)
                           && prop.typeName.equals("ChangeSummary")))
                     {
                       dataFactory->setDASValue(

Modified: incubator/tuscany/cpp/sdo/runtime/core/test/48736_xml.txt
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sdo/runtime/core/test/48736_xml.txt?rev=569777&r1=569776&r2=569777&view=diff
==============================================================================
--- incubator/tuscany/cpp/sdo/runtime/core/test/48736_xml.txt (original)
+++ incubator/tuscany/cpp/sdo/runtime/core/test/48736_xml.txt Sun Aug 26 01:44:46 2007
@@ -12,8 +12,6 @@
 Type:TNS#RootType
 Property:formalname  of type FormalNameType
 Property:last  of type String
-Type:commonj.sdo#BigDecimal
-Type:commonj.sdo#BigInteger
 Type:commonj.sdo#Boolean
 Type:commonj.sdo#Byte
 Type:commonj.sdo#Bytes
@@ -21,8 +19,10 @@
 Type:commonj.sdo#Character
 Type:commonj.sdo#DataObject
 Type:commonj.sdo#Date
+Type:commonj.sdo#Decimal
 Type:commonj.sdo#Double
 Type:commonj.sdo#Float
+Type:commonj.sdo#Int
 Type:commonj.sdo#Integer
 Type:commonj.sdo#Long
 Type:commonj.sdo#OpenDataObject

Modified: incubator/tuscany/cpp/sdo/runtime/core/test/48736_xsd.txt
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sdo/runtime/core/test/48736_xsd.txt?rev=569777&r1=569776&r2=569777&view=diff
==============================================================================
--- incubator/tuscany/cpp/sdo/runtime/core/test/48736_xsd.txt (original)
+++ incubator/tuscany/cpp/sdo/runtime/core/test/48736_xsd.txt Sun Aug 26 01:44:46 2007
@@ -9,8 +9,6 @@
 Type:TNS#RootType
 Property:formalname  of type FormalNameType
 Property:last  of type String
-Type:commonj.sdo#BigDecimal
-Type:commonj.sdo#BigInteger
 Type:commonj.sdo#Boolean
 Type:commonj.sdo#Byte
 Type:commonj.sdo#Bytes
@@ -18,8 +16,10 @@
 Type:commonj.sdo#Character
 Type:commonj.sdo#DataObject
 Type:commonj.sdo#Date
+Type:commonj.sdo#Decimal
 Type:commonj.sdo#Double
 Type:commonj.sdo#Float
+Type:commonj.sdo#Int
 Type:commonj.sdo#Integer
 Type:commonj.sdo#Long
 Type:commonj.sdo#OpenDataObject

Modified: incubator/tuscany/cpp/sdo/runtime/core/test/b47137b.txt
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sdo/runtime/core/test/b47137b.txt?rev=569777&r1=569776&r2=569777&view=diff
==============================================================================
--- incubator/tuscany/cpp/sdo/runtime/core/test/b47137b.txt (original)
+++ incubator/tuscany/cpp/sdo/runtime/core/test/b47137b.txt Sun Aug 26 01:44:46 2007
@@ -1,5 +1,3 @@
-Type:commonj.sdo#BigDecimal
-Type:commonj.sdo#BigInteger
 Type:commonj.sdo#Boolean
 Type:commonj.sdo#Byte
 Type:commonj.sdo#Bytes
@@ -7,8 +5,10 @@
 Type:commonj.sdo#Character
 Type:commonj.sdo#DataObject
 Type:commonj.sdo#Date
+Type:commonj.sdo#Decimal
 Type:commonj.sdo#Double
 Type:commonj.sdo#Float
+Type:commonj.sdo#Int
 Type:commonj.sdo#Integer
 Type:commonj.sdo#Long
 Type:commonj.sdo#OpenDataObject

Modified: incubator/tuscany/cpp/sdo/runtime/core/test/b47293.txt
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sdo/runtime/core/test/b47293.txt?rev=569777&r1=569776&r2=569777&view=diff
==============================================================================
--- incubator/tuscany/cpp/sdo/runtime/core/test/b47293.txt (original)
+++ incubator/tuscany/cpp/sdo/runtime/core/test/b47293.txt Sun Aug 26 01:44:46 2007
@@ -1,7 +1,5 @@
-Type:catalogNS#CatalogTypeType:catalogNS#RootTypeType:commonj.sdo#BigDecimalType:commonj.sdo#BigIntegerType:commonj.sdo#BooleanType:commonj.sdo#ByteType:commonj.sdo#BytesType:commonj.sdo#ChangeSummaryType:commonj.sdo#CharacterType:commonj.sdo#DataObjectType:commonj.sdo#DateType:commonj.sdo#DoubleType:commonj.sdo#FloatType:commonj.sdo#IntegerType:commonj.sdo#LongType:commonj.sdo#OpenDataObjectType:commonj.sdo#ShortType:commonj.sdo#StringType:commonj.sdo#URIType:customerNS#AddressTypeType:customerNS#CustomerTypeType:customerNS#PaymentTypeType:customerNS#RootTypeType:orderNS#OrderStatusType:orderNS#OrderTypeType:orderNS#RootTypeType:orderNS#itemType:catalogNS#CatalogType
+Type:catalogNS#CatalogTypeType:catalogNS#RootTypeType:commonj.sdo#BooleanType:commonj.sdo#ByteType:commonj.sdo#BytesType:commonj.sdo#ChangeSummaryType:commonj.sdo#CharacterType:commonj.sdo#DataObjectType:commonj.sdo#DateType:commonj.sdo#DecimalType:commonj.sdo#DoubleType:commonj.sdo#FloatType:commonj.sdo#IntType:commonj.sdo#IntegerType:commonj.sdo#LongType:commonj.sdo#OpenDataObjectType:commonj.sdo#ShortType:commonj.sdo#StringType:commonj.sdo#URIType:customerNS#AddressTypeType:customerNS#CustomerTypeType:customerNS#PaymentTypeType:customerNS#RootTypeType:orderNS#OrderStatusType:orderNS#OrderTypeType:orderNS#RootTypeType:orderNS#itemType:catalogNS#CatalogType
 Type:catalogNS#RootType
-Type:commonj.sdo#BigDecimal
-Type:commonj.sdo#BigInteger
 Type:commonj.sdo#Boolean
 Type:commonj.sdo#Byte
 Type:commonj.sdo#Bytes
@@ -9,8 +7,10 @@
 Type:commonj.sdo#Character
 Type:commonj.sdo#DataObject
 Type:commonj.sdo#Date
+Type:commonj.sdo#Decimal
 Type:commonj.sdo#Double
 Type:commonj.sdo#Float
+Type:commonj.sdo#Int
 Type:commonj.sdo#Integer
 Type:commonj.sdo#Long
 Type:commonj.sdo#OpenDataObject

Modified: incubator/tuscany/cpp/sdo/runtime/core/test/b48633b_xsd.txt
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sdo/runtime/core/test/b48633b_xsd.txt?rev=569777&r1=569776&r2=569777&view=diff
==============================================================================
--- incubator/tuscany/cpp/sdo/runtime/core/test/b48633b_xsd.txt (original)
+++ incubator/tuscany/cpp/sdo/runtime/core/test/b48633b_xsd.txt Sun Aug 26 01:44:46 2007
@@ -1,8 +1,6 @@
 ***** TESTANY ******************************************
 Type:TNS#RootType
 Property:version  of type String
-Type:commonj.sdo#BigDecimal
-Type:commonj.sdo#BigInteger
 Type:commonj.sdo#Boolean
 Type:commonj.sdo#Byte
 Type:commonj.sdo#Bytes
@@ -10,8 +8,10 @@
 Type:commonj.sdo#Character
 Type:commonj.sdo#DataObject
 Type:commonj.sdo#Date
+Type:commonj.sdo#Decimal
 Type:commonj.sdo#Double
 Type:commonj.sdo#Float
+Type:commonj.sdo#Int
 Type:commonj.sdo#Integer
 Type:commonj.sdo#Long
 Type:commonj.sdo#OpenDataObject

Modified: incubator/tuscany/cpp/sdo/runtime/core/test/b48636_xml.txt
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sdo/runtime/core/test/b48636_xml.txt?rev=569777&r1=569776&r2=569777&view=diff
==============================================================================
--- incubator/tuscany/cpp/sdo/runtime/core/test/b48636_xml.txt (original)
+++ incubator/tuscany/cpp/sdo/runtime/core/test/b48636_xml.txt Sun Aug 26 01:44:46 2007
@@ -1,6 +1,4 @@
 ***** TYPES AFTER RESOLVE*********************************
-Type:commonj.sdo#BigDecimal
-Type:commonj.sdo#BigInteger
 Type:commonj.sdo#Boolean
 Type:commonj.sdo#Byte
 Type:commonj.sdo#Bytes
@@ -8,8 +6,10 @@
 Type:commonj.sdo#Character
 Type:commonj.sdo#DataObject
 Type:commonj.sdo#Date
+Type:commonj.sdo#Decimal
 Type:commonj.sdo#Double
 Type:commonj.sdo#Float
+Type:commonj.sdo#Int
 Type:commonj.sdo#Integer
 Type:commonj.sdo#Long
 Type:commonj.sdo#OpenDataObject

Modified: incubator/tuscany/cpp/sdo/runtime/core/test/b48636_xsd.txt
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sdo/runtime/core/test/b48636_xsd.txt?rev=569777&r1=569776&r2=569777&view=diff
==============================================================================
--- incubator/tuscany/cpp/sdo/runtime/core/test/b48636_xsd.txt (original)
+++ incubator/tuscany/cpp/sdo/runtime/core/test/b48636_xsd.txt Sun Aug 26 01:44:46 2007
@@ -1,6 +1,4 @@
 ***** TYPES BEFORE RESOLVE **********************************
-Type:commonj.sdo#BigDecimal
-Type:commonj.sdo#BigInteger
 Type:commonj.sdo#Boolean
 Type:commonj.sdo#Byte
 Type:commonj.sdo#Bytes
@@ -8,8 +6,10 @@
 Type:commonj.sdo#Character
 Type:commonj.sdo#DataObject
 Type:commonj.sdo#Date
+Type:commonj.sdo#Decimal
 Type:commonj.sdo#Double
 Type:commonj.sdo#Float
+Type:commonj.sdo#Int
 Type:commonj.sdo#Integer
 Type:commonj.sdo#Long
 Type:commonj.sdo#OpenDataObject

Modified: incubator/tuscany/cpp/sdo/runtime/core/test/b48686_xml.txt
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sdo/runtime/core/test/b48686_xml.txt?rev=569777&r1=569776&r2=569777&view=diff
==============================================================================
--- incubator/tuscany/cpp/sdo/runtime/core/test/b48686_xml.txt (original)
+++ incubator/tuscany/cpp/sdo/runtime/core/test/b48686_xml.txt Sun Aug 26 01:44:46 2007
@@ -1,6 +1,4 @@
 ***** TYPES AFTER RESOLVE*********************************
-Type:commonj.sdo#BigDecimal
-Type:commonj.sdo#BigInteger
 Type:commonj.sdo#Boolean
 Type:commonj.sdo#Byte
 Type:commonj.sdo#Bytes
@@ -8,8 +6,10 @@
 Type:commonj.sdo#Character
 Type:commonj.sdo#DataObject
 Type:commonj.sdo#Date
+Type:commonj.sdo#Decimal
 Type:commonj.sdo#Double
 Type:commonj.sdo#Float
+Type:commonj.sdo#Int
 Type:commonj.sdo#Integer
 Type:commonj.sdo#Long
 Type:commonj.sdo#OpenDataObject
@@ -35,11 +35,11 @@
 
 ages: list dataObject[0]=
 ===== DataObject contents =====
-values: list integer[0]=1
+values: list string[0]=1
 
-integer[1]=2
+string[1]=2
 
-integer[2]=3
+string[2]=3
 
 ===== End DataObject =====
 

Modified: incubator/tuscany/cpp/sdo/runtime/core/test/b48686_xsd.txt
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sdo/runtime/core/test/b48686_xsd.txt?rev=569777&r1=569776&r2=569777&view=diff
==============================================================================
--- incubator/tuscany/cpp/sdo/runtime/core/test/b48686_xsd.txt (original)
+++ incubator/tuscany/cpp/sdo/runtime/core/test/b48686_xsd.txt Sun Aug 26 01:44:46 2007
@@ -1,6 +1,4 @@
 ***** TYPES BEFORE RESOLVE **********************************
-Type:commonj.sdo#BigDecimal
-Type:commonj.sdo#BigInteger
 Type:commonj.sdo#Boolean
 Type:commonj.sdo#Byte
 Type:commonj.sdo#Bytes
@@ -8,8 +6,10 @@
 Type:commonj.sdo#Character
 Type:commonj.sdo#DataObject
 Type:commonj.sdo#Date
+Type:commonj.sdo#Decimal
 Type:commonj.sdo#Double
 Type:commonj.sdo#Float
+Type:commonj.sdo#Int
 Type:commonj.sdo#Integer
 Type:commonj.sdo#Long
 Type:commonj.sdo#OpenDataObject

Modified: incubator/tuscany/cpp/sdo/runtime/core/test/bothgroups_xsd.txt
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sdo/runtime/core/test/bothgroups_xsd.txt?rev=569777&r1=569776&r2=569777&view=diff
==============================================================================
--- incubator/tuscany/cpp/sdo/runtime/core/test/bothgroups_xsd.txt (original)
+++ incubator/tuscany/cpp/sdo/runtime/core/test/bothgroups_xsd.txt Sun Aug 26 01:44:46 2007
@@ -1,6 +1,4 @@
 ***** TYPES BEFORE RESOLVE **********************************
-Type:commonj.sdo#BigDecimal
-Type:commonj.sdo#BigInteger
 Type:commonj.sdo#Boolean
 Type:commonj.sdo#Byte
 Type:commonj.sdo#Bytes
@@ -8,8 +6,10 @@
 Type:commonj.sdo#Character
 Type:commonj.sdo#DataObject
 Type:commonj.sdo#Date
+Type:commonj.sdo#Decimal
 Type:commonj.sdo#Double
 Type:commonj.sdo#Float
+Type:commonj.sdo#Int
 Type:commonj.sdo#Integer
 Type:commonj.sdo#Long
 Type:commonj.sdo#OpenDataObject

Modified: incubator/tuscany/cpp/sdo/runtime/core/test/bothgroupssamename_xsd.txt
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sdo/runtime/core/test/bothgroupssamename_xsd.txt?rev=569777&r1=569776&r2=569777&view=diff
==============================================================================
--- incubator/tuscany/cpp/sdo/runtime/core/test/bothgroupssamename_xsd.txt (original)
+++ incubator/tuscany/cpp/sdo/runtime/core/test/bothgroupssamename_xsd.txt Sun Aug 26 01:44:46 2007
@@ -1,6 +1,4 @@
 ***** TYPES BEFORE RESOLVE **********************************
-Type:commonj.sdo#BigDecimal
-Type:commonj.sdo#BigInteger
 Type:commonj.sdo#Boolean
 Type:commonj.sdo#Byte
 Type:commonj.sdo#Bytes
@@ -8,8 +6,10 @@
 Type:commonj.sdo#Character
 Type:commonj.sdo#DataObject
 Type:commonj.sdo#Date
+Type:commonj.sdo#Decimal
 Type:commonj.sdo#Double
 Type:commonj.sdo#Float
+Type:commonj.sdo#Int
 Type:commonj.sdo#Integer
 Type:commonj.sdo#Long
 Type:commonj.sdo#OpenDataObject

Modified: incubator/tuscany/cpp/sdo/runtime/core/test/bug48300_xml.txt
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sdo/runtime/core/test/bug48300_xml.txt?rev=569777&r1=569776&r2=569777&view=diff
==============================================================================
--- incubator/tuscany/cpp/sdo/runtime/core/test/bug48300_xml.txt (original)
+++ incubator/tuscany/cpp/sdo/runtime/core/test/bug48300_xml.txt Sun Aug 26 01:44:46 2007
@@ -1,6 +1,4 @@
 ***** TYPES AFTER RESOLVE*********************************
-Type:commonj.sdo#BigDecimal
-Type:commonj.sdo#BigInteger
 Type:commonj.sdo#Boolean
 Type:commonj.sdo#Byte
 Type:commonj.sdo#Bytes
@@ -8,8 +6,10 @@
 Type:commonj.sdo#Character
 Type:commonj.sdo#DataObject
 Type:commonj.sdo#Date
+Type:commonj.sdo#Decimal
 Type:commonj.sdo#Double
 Type:commonj.sdo#Float
+Type:commonj.sdo#Int
 Type:commonj.sdo#Integer
 Type:commonj.sdo#Long
 Type:commonj.sdo#OpenDataObject

Modified: incubator/tuscany/cpp/sdo/runtime/core/test/bug48300_xsd.txt
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sdo/runtime/core/test/bug48300_xsd.txt?rev=569777&r1=569776&r2=569777&view=diff
==============================================================================
--- incubator/tuscany/cpp/sdo/runtime/core/test/bug48300_xsd.txt (original)
+++ incubator/tuscany/cpp/sdo/runtime/core/test/bug48300_xsd.txt Sun Aug 26 01:44:46 2007
@@ -1,6 +1,4 @@
 ***** TYPES BEFORE RESOLVE **********************************
-Type:commonj.sdo#BigDecimal
-Type:commonj.sdo#BigInteger
 Type:commonj.sdo#Boolean
 Type:commonj.sdo#Byte
 Type:commonj.sdo#Bytes
@@ -8,8 +6,10 @@
 Type:commonj.sdo#Character
 Type:commonj.sdo#DataObject
 Type:commonj.sdo#Date
+Type:commonj.sdo#Decimal
 Type:commonj.sdo#Double
 Type:commonj.sdo#Float
+Type:commonj.sdo#Int
 Type:commonj.sdo#Integer
 Type:commonj.sdo#Long
 Type:commonj.sdo#OpenDataObject

Modified: incubator/tuscany/cpp/sdo/runtime/core/test/bunique-out.txt
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sdo/runtime/core/test/bunique-out.txt?rev=569777&r1=569776&r2=569777&view=diff
==============================================================================
--- incubator/tuscany/cpp/sdo/runtime/core/test/bunique-out.txt (original)
+++ incubator/tuscany/cpp/sdo/runtime/core/test/bunique-out.txt Sun Aug 26 01:44:46 2007
@@ -1 +1 @@
-<xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:sdo="commonj.sdo" xmlns:sdoxml="commonj.sdo/xml" xmlns:tns1="nottest" xmlns:tns="test" targetNamespace="test"><xsd:element name="duplicate" type="tns1:Duplicate"/><xsd:complexType name="tns1:Duplicate"><xsd:sequence><xsd:element name="ob" type="tns:Object" minOccurs="0"/></xsd:sequence><xsd:attribute name="id" type="xsd:integer"/></xsd:complexType><xsd:element name="duplicate" type="Duplicate"/><xsd:complexType name="Duplicate"><xsd:sequence><xsd:element name="ob" type="tns:Object" minOccurs="0"/></xsd:sequence><xsd:attribute name="id" type="xsd:integer"/></xsd:complexType><xsd:element name="object" type="Object"/><xsd:complexType name="Object"/><xsd:element name="root" type="Root"/><xsd:complexType name="Root"><xsd:sequence><xsd:element name="duplicate" type="tns:Duplicate" minOccurs="0"/><xsd:element name="duplicate2" type="tns1:Duplicate" minOccurs="0"/><xsd:element name="unique" type="tns:Unique" minOccurs="0
 "/><xsd:element name="duplicatelist" type="tns:Duplicate" minOccurs="0" maxOccurs="unbounded"/><xsd:element name="duplicatelist2" type="tns1:Duplicate" minOccurs="0" maxOccurs="unbounded"/><xsd:element name="uniquelist" type="tns:Unique" minOccurs="0" maxOccurs="unbounded"/></xsd:sequence></xsd:complexType><xsd:element name="unique" type="Unique"/><xsd:complexType name="Unique"><xsd:sequence><xsd:element name="ob" type="tns:Object" minOccurs="0"/></xsd:sequence><xsd:attribute name="id" type="xsd:integer"/></xsd:complexType></xsd:schema>
\ No newline at end of file
+<xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:sdo="commonj.sdo" xmlns:sdoxml="commonj.sdo/xml" xmlns:tns1="nottest" xmlns:tns="test" targetNamespace="test"><xsd:element name="duplicate" type="tns1:Duplicate"/><xsd:complexType name="tns1:Duplicate"><xsd:sequence><xsd:element name="ob" type="tns:Object" minOccurs="0"/></xsd:sequence><xsd:attribute name="id" type="xsd:int"/></xsd:complexType><xsd:element name="duplicate" type="Duplicate"/><xsd:complexType name="Duplicate"><xsd:sequence><xsd:element name="ob" type="tns:Object" minOccurs="0"/></xsd:sequence><xsd:attribute name="id" type="xsd:int"/></xsd:complexType><xsd:element name="object" type="Object"/><xsd:complexType name="Object"/><xsd:element name="root" type="Root"/><xsd:complexType name="Root"><xsd:sequence><xsd:element name="duplicate" type="tns:Duplicate" minOccurs="0"/><xsd:element name="duplicate2" type="tns1:Duplicate" minOccurs="0"/><xsd:element name="unique" type="tns:Unique" minOccurs="0"/><xsd:
 element name="duplicatelist" type="tns:Duplicate" minOccurs="0" maxOccurs="unbounded"/><xsd:element name="duplicatelist2" type="tns1:Duplicate" minOccurs="0" maxOccurs="unbounded"/><xsd:element name="uniquelist" type="tns:Unique" minOccurs="0" maxOccurs="unbounded"/></xsd:sequence></xsd:complexType><xsd:element name="unique" type="Unique"/><xsd:complexType name="Unique"><xsd:sequence><xsd:element name="ob" type="tns:Object" minOccurs="0"/></xsd:sequence><xsd:attribute name="id" type="xsd:int"/></xsd:complexType></xsd:schema>
\ No newline at end of file

Modified: incubator/tuscany/cpp/sdo/runtime/core/test/grouprefingroup_xsd.txt
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sdo/runtime/core/test/grouprefingroup_xsd.txt?rev=569777&r1=569776&r2=569777&view=diff
==============================================================================
--- incubator/tuscany/cpp/sdo/runtime/core/test/grouprefingroup_xsd.txt (original)
+++ incubator/tuscany/cpp/sdo/runtime/core/test/grouprefingroup_xsd.txt Sun Aug 26 01:44:46 2007
@@ -1,6 +1,4 @@
 ***** TYPES BEFORE RESOLVE **********************************
-Type:commonj.sdo#BigDecimal
-Type:commonj.sdo#BigInteger
 Type:commonj.sdo#Boolean
 Type:commonj.sdo#Byte
 Type:commonj.sdo#Bytes
@@ -8,8 +6,10 @@
 Type:commonj.sdo#Character
 Type:commonj.sdo#DataObject
 Type:commonj.sdo#Date
+Type:commonj.sdo#Decimal
 Type:commonj.sdo#Double
 Type:commonj.sdo#Float
+Type:commonj.sdo#Int
 Type:commonj.sdo#Integer
 Type:commonj.sdo#Long
 Type:commonj.sdo#OpenDataObject

Modified: incubator/tuscany/cpp/sdo/runtime/core/test/grouptoolate_xsd.txt
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sdo/runtime/core/test/grouptoolate_xsd.txt?rev=569777&r1=569776&r2=569777&view=diff
==============================================================================
--- incubator/tuscany/cpp/sdo/runtime/core/test/grouptoolate_xsd.txt (original)
+++ incubator/tuscany/cpp/sdo/runtime/core/test/grouptoolate_xsd.txt Sun Aug 26 01:44:46 2007
@@ -1,6 +1,4 @@
 ***** TYPES BEFORE RESOLVE **********************************
-Type:commonj.sdo#BigDecimal
-Type:commonj.sdo#BigInteger
 Type:commonj.sdo#Boolean
 Type:commonj.sdo#Byte
 Type:commonj.sdo#Bytes
@@ -8,8 +6,10 @@
 Type:commonj.sdo#Character
 Type:commonj.sdo#DataObject
 Type:commonj.sdo#Date
+Type:commonj.sdo#Decimal
 Type:commonj.sdo#Double
 Type:commonj.sdo#Float
+Type:commonj.sdo#Int
 Type:commonj.sdo#Integer
 Type:commonj.sdo#Long
 Type:commonj.sdo#OpenDataObject

Modified: incubator/tuscany/cpp/sdo/runtime/core/test/groupwithprefix_xsd.txt
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sdo/runtime/core/test/groupwithprefix_xsd.txt?rev=569777&r1=569776&r2=569777&view=diff
==============================================================================
--- incubator/tuscany/cpp/sdo/runtime/core/test/groupwithprefix_xsd.txt (original)
+++ incubator/tuscany/cpp/sdo/runtime/core/test/groupwithprefix_xsd.txt Sun Aug 26 01:44:46 2007
@@ -1,6 +1,4 @@
 ***** TYPES BEFORE RESOLVE **********************************
-Type:commonj.sdo#BigDecimal
-Type:commonj.sdo#BigInteger
 Type:commonj.sdo#Boolean
 Type:commonj.sdo#Byte
 Type:commonj.sdo#Bytes
@@ -8,8 +6,10 @@
 Type:commonj.sdo#Character
 Type:commonj.sdo#DataObject
 Type:commonj.sdo#Date
+Type:commonj.sdo#Decimal
 Type:commonj.sdo#Double
 Type:commonj.sdo#Float
+Type:commonj.sdo#Int
 Type:commonj.sdo#Integer
 Type:commonj.sdo#Long
 Type:commonj.sdo#OpenDataObject

Modified: incubator/tuscany/cpp/sdo/runtime/core/test/inc1.txt
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sdo/runtime/core/test/inc1.txt?rev=569777&r1=569776&r2=569777&view=diff
==============================================================================
--- incubator/tuscany/cpp/sdo/runtime/core/test/inc1.txt (original)
+++ incubator/tuscany/cpp/sdo/runtime/core/test/inc1.txt Sun Aug 26 01:44:46 2007
@@ -1,5 +1,3 @@
-Type:commonj.sdo#BigDecimal
-Type:commonj.sdo#BigInteger
 Type:commonj.sdo#Boolean
 Type:commonj.sdo#Byte
 Type:commonj.sdo#Bytes
@@ -7,8 +5,10 @@
 Type:commonj.sdo#Character
 Type:commonj.sdo#DataObject
 Type:commonj.sdo#Date
+Type:commonj.sdo#Decimal
 Type:commonj.sdo#Double
 Type:commonj.sdo#Float
+Type:commonj.sdo#Int
 Type:commonj.sdo#Integer
 Type:commonj.sdo#Long
 Type:commonj.sdo#OpenDataObject

Modified: incubator/tuscany/cpp/sdo/runtime/core/test/inc2.txt
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sdo/runtime/core/test/inc2.txt?rev=569777&r1=569776&r2=569777&view=diff
==============================================================================
--- incubator/tuscany/cpp/sdo/runtime/core/test/inc2.txt (original)
+++ incubator/tuscany/cpp/sdo/runtime/core/test/inc2.txt Sun Aug 26 01:44:46 2007
@@ -1,5 +1,3 @@
-Type:commonj.sdo#BigDecimal
-Type:commonj.sdo#BigInteger
 Type:commonj.sdo#Boolean
 Type:commonj.sdo#Byte
 Type:commonj.sdo#Bytes
@@ -7,8 +5,10 @@
 Type:commonj.sdo#Character
 Type:commonj.sdo#DataObject
 Type:commonj.sdo#Date
+Type:commonj.sdo#Decimal
 Type:commonj.sdo#Double
 Type:commonj.sdo#Float
+Type:commonj.sdo#Int
 Type:commonj.sdo#Integer
 Type:commonj.sdo#Long
 Type:commonj.sdo#OpenDataObject

Modified: incubator/tuscany/cpp/sdo/runtime/core/test/jira490.txt
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sdo/runtime/core/test/jira490.txt?rev=569777&r1=569776&r2=569777&view=diff
==============================================================================
--- incubator/tuscany/cpp/sdo/runtime/core/test/jira490.txt (original)
+++ incubator/tuscany/cpp/sdo/runtime/core/test/jira490.txt Sun Aug 26 01:44:46 2007
@@ -3,8 +3,6 @@
 Before Resolution
 
 Printing Types
-Type BigDecimal
-Type BigInteger
 Type Boolean
 Type Byte
 Type Bytes
@@ -12,8 +10,10 @@
 Type Character
 Type DataObject
 Type Date
+Type Decimal
 Type Double
 Type Float
+Type Int
 Type Integer
 Type Long
 Type OpenDataObject
@@ -27,8 +27,6 @@
 After Resolution
 
 Printing Types
-Type BigDecimal
-Type BigInteger
 Type Boolean
 Type Byte
 Type Bytes
@@ -36,8 +34,10 @@
 Type Character
 Type DataObject
 Type Date
+Type Decimal
 Type Double
 Type Float
+Type Int
 Type Integer
 Type Long
 Type OpenDataObject

Modified: incubator/tuscany/cpp/sdo/runtime/core/test/list1.xsd
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sdo/runtime/core/test/list1.xsd?rev=569777&r1=569776&r2=569777&view=diff
==============================================================================
--- incubator/tuscany/cpp/sdo/runtime/core/test/list1.xsd (original)
+++ incubator/tuscany/cpp/sdo/runtime/core/test/list1.xsd Sun Aug 26 01:44:46 2007
@@ -30,7 +30,7 @@
 </xs:complexType>
 
 <xs:simpleType name="intListType">
-    <xs:list itemType="xs:integer"/>
+    <xs:list itemType="xs:int"/>
 </xs:simpleType>
  
 <xs:simpleType name="stringListType">
@@ -38,3 +38,7 @@
 </xs:simpleType>
 
 </xs:schema>
+
+
+
+

Modified: incubator/tuscany/cpp/sdo/runtime/core/test/list1_xml.txt
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sdo/runtime/core/test/list1_xml.txt?rev=569777&r1=569776&r2=569777&view=diff
==============================================================================
--- incubator/tuscany/cpp/sdo/runtime/core/test/list1_xml.txt (original)
+++ incubator/tuscany/cpp/sdo/runtime/core/test/list1_xml.txt Sun Aug 26 01:44:46 2007
@@ -1,6 +1,4 @@
 ***** TYPES AFTER RESOLVE*********************************
-Type:commonj.sdo#BigDecimal
-Type:commonj.sdo#BigInteger
 Type:commonj.sdo#Boolean
 Type:commonj.sdo#Byte
 Type:commonj.sdo#Bytes
@@ -8,8 +6,10 @@
 Type:commonj.sdo#Character
 Type:commonj.sdo#DataObject
 Type:commonj.sdo#Date
+Type:commonj.sdo#Decimal
 Type:commonj.sdo#Double
 Type:commonj.sdo#Float
+Type:commonj.sdo#Int
 Type:commonj.sdo#Integer
 Type:commonj.sdo#Long
 Type:commonj.sdo#OpenDataObject
@@ -19,7 +19,7 @@
 Type:http://www.wrox.com/name#RootType
 Property:listtest  of type listTestType
 Type:http://www.wrox.com/name#intListType
-Property:values (many)  of type Integer
+Property:values (many)  of type Int
 Type:http://www.wrox.com/name#listTestType
 Property:integers (many)  of type intListType
 Property:strings (many)  of type stringListType
@@ -29,23 +29,23 @@
 ===== DataObject contents =====
 integers: list dataObject[0]=
 ===== DataObject contents =====
-values: list integer[0]=1
+values: list int[0]=1
 
-integer[1]=2
+int[1]=2
 
-integer[2]=3
+int[2]=3
 
-integer[3]=4
+int[3]=4
 
-integer[4]=5
+int[4]=5
 
-integer[5]=6
+int[5]=6
 
-integer[6]=7
+int[6]=7
 
-integer[7]=8
+int[7]=8
 
-integer[8]=9
+int[8]=9
 
 ===== End DataObject =====
 

Modified: incubator/tuscany/cpp/sdo/runtime/core/test/list1_xsd.txt
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sdo/runtime/core/test/list1_xsd.txt?rev=569777&r1=569776&r2=569777&view=diff
==============================================================================
--- incubator/tuscany/cpp/sdo/runtime/core/test/list1_xsd.txt (original)
+++ incubator/tuscany/cpp/sdo/runtime/core/test/list1_xsd.txt Sun Aug 26 01:44:46 2007
@@ -1,6 +1,4 @@
 ***** TYPES BEFORE RESOLVE **********************************
-Type:commonj.sdo#BigDecimal
-Type:commonj.sdo#BigInteger
 Type:commonj.sdo#Boolean
 Type:commonj.sdo#Byte
 Type:commonj.sdo#Bytes
@@ -8,8 +6,10 @@
 Type:commonj.sdo#Character
 Type:commonj.sdo#DataObject
 Type:commonj.sdo#Date
+Type:commonj.sdo#Decimal
 Type:commonj.sdo#Double
 Type:commonj.sdo#Float
+Type:commonj.sdo#Int
 Type:commonj.sdo#Integer
 Type:commonj.sdo#Long
 Type:commonj.sdo#OpenDataObject
@@ -19,7 +19,7 @@
 Type:http://www.wrox.com/name#RootType
 Property:listtest  of type listTestType
 Type:http://www.wrox.com/name#intListType
-Property:values (many)  of type Integer
+Property:values (many)  of type Int
 Type:http://www.wrox.com/name#listTestType
 Property:integers (many)  of type intListType
 Property:strings (many)  of type stringListType

Modified: incubator/tuscany/cpp/sdo/runtime/core/test/maintest.txt
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sdo/runtime/core/test/maintest.txt?rev=569777&r1=569776&r2=569777&view=diff
==============================================================================
--- incubator/tuscany/cpp/sdo/runtime/core/test/maintest.txt (original)
+++ incubator/tuscany/cpp/sdo/runtime/core/test/maintest.txt Sun Aug 26 01:44:46 2007
@@ -14,8 +14,6 @@
 Manager is sequenced?1
 BEFORE RESOLUTION
 Printing Types
-Type BigDecimal
-Type BigInteger
 Type Boolean
 Type Byte
 Type Bytes
@@ -23,8 +21,10 @@
 Type Character
 Type DataObject
 Type Date
+Type Decimal
 Type Double
 Type Float
+Type Int
 Type Integer
 Type Long
 Type OpenDataObject
@@ -43,7 +43,7 @@
 Has Property subdepartments of type SubDepartment
 Type Department
 Has Property name of type String
-Has Property id of type Integer
+Has Property id of type Int
 Has Property manager of type Manager
 Has Property employees of type Employee
 Type DerivedString
@@ -58,7 +58,7 @@
 Has Property byte of type Byte
 Has Property character of type Character
 Has Property short of type Short
-Has Property long of type Integer
+Has Property long of type Int
 Has Property longlong of type Long
 Has Property float of type Float
 Has Property longdouble of type Double
@@ -72,8 +72,6 @@
 Has Property subname of type String
 AFTER RESOLUTION
 Printing Types
-Type BigDecimal
-Type BigInteger
 Type Boolean
 Type Byte
 Type Bytes
@@ -81,8 +79,10 @@
 Type Character
 Type DataObject
 Type Date
+Type Decimal
 Type Double
 Type Float
+Type Int
 Type Integer
 Type Long
 Type OpenDataObject
@@ -101,7 +101,7 @@
 Has Property subdepartments of type SubDepartment
 Type Department
 Has Property name of type String
-Has Property id of type Integer
+Has Property id of type Int
 Has Property manager of type Manager
 Has Property employees of type Employee
 Type DerivedString
@@ -120,7 +120,7 @@
 Has Property byte of type Byte
 Has Property character of type Character
 Has Property short of type Short
-Has Property long of type Integer
+Has Property long of type Int
 Has Property longlong of type Long
 Has Property float of type Float
 Has Property longdouble of type Double
@@ -132,7 +132,7 @@
 Has Property name of type String
 Type SubDepartment
 Has Property name of type String
-Has Property id of type Integer
+Has Property id of type Int
 Has Property manager of type Manager
 Has Property employees of type Employee
 Has Property subname of type String

Modified: incubator/tuscany/cpp/sdo/runtime/core/test/sdotest.cpp
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sdo/runtime/core/test/sdotest.cpp?rev=569777&r1=569776&r2=569777&view=diff
==============================================================================
--- incubator/tuscany/cpp/sdo/runtime/core/test/sdotest.cpp (original)
+++ incubator/tuscany/cpp/sdo/runtime/core/test/sdotest.cpp Sun Aug 26 01:44:46 2007
@@ -36,6 +36,7 @@
 
 
 using namespace commonj::sdo;
+using namespace commonj::sdo::internal;
 
 
 
@@ -304,7 +305,7 @@
    
     const Type& tmain   = mdg->getType("companyNS","MainType");
     const Type& tshort  = mdg->getType("commonj.sdo","Short");
-    const Type& tint    = mdg->getType("commonj.sdo","Integer");
+    const Type& tint    = mdg->getType("commonj.sdo","Int");
 
         
     mdg->addPropertyToType(tmain,"short",tshort,true);
@@ -322,7 +323,7 @@
 
     catch (SDORuntimeException e)
     {
-        if (!silent) cout << "Unsigned integer test failed" << endl << e << endl;
+        if (!silent) cout << "Unsigned int test failed" << endl << e << endl;
         return 0;
     }
     
@@ -894,7 +895,7 @@
     if (!testGetter(dor,"byte")) return 0;
     if (!testGetter(dor,"character")) return 0;
     if (!testGetter(dor,"short")) return 0;
-    if (!testGetter(dor,"integer")) return 0;
+    if (!testGetter(dor,"int")) return 0;
     if (!testGetter(dor,"long")) return 0;
     if (!testGetter(dor,"double")) return 0;
     if (!testGetter(dor,"float")) return 0;
@@ -995,7 +996,7 @@
    }
 
    try {
-      int i = dor->getInteger(str);
+      int i = dor->getInt(str);
    }
    catch (SDOPropertyNotSetException pe)
    {
@@ -1254,7 +1255,7 @@
    mdg->addPropertyToType("myspace","Container","byte","commonj.sdo","Byte");
    mdg->addPropertyToType("myspace","Container","character","commonj.sdo","Character");
    mdg->addPropertyToType("myspace","Container","short","commonj.sdo","Short");
-   mdg->addPropertyToType("myspace","Container","integer","commonj.sdo","Integer");
+   mdg->addPropertyToType("myspace","Container","int","commonj.sdo","Int");
    mdg->addPropertyToType("myspace","Container","long","commonj.sdo","Long");
    mdg->addPropertyToType("myspace","Container","float","commonj.sdo","Float");
    mdg->addPropertyToType("myspace","Container","double","commonj.sdo","Double");
@@ -1299,7 +1300,7 @@
    dor->setByte("byte",20);
    dor->setCharacter("character", 1000);
    dor->setShort("short", (short)12345678);
-   dor->setInteger("integer", 87654321);
+   dor->setInt("int", 87654321);
    dor->setLong("long", largeInt);
    dor->setFloat("float", (float)12345.678);
    dor->setDouble("double", 1234567.891);
@@ -1345,7 +1346,7 @@
     mdg->addPropertyToType(tm,"unsetobject","myspace","AnObject");
 
     // many valued...
-    mdg->addPropertyToType(tm,"longs",        "commonj.sdo","Integer", true);
+    mdg->addPropertyToType(tm,"longs",        "commonj.sdo","Int", true);
     mdg->addPropertyToType(tm,"objects",     "myspace","AnObject", true);
 
     mdg->addPropertyToType(tr,"usertest",     "myspace","UserTest");
@@ -1499,11 +1500,11 @@
 
     mdg->setDefault("myspace","DefaultTest","short", (short)300);
 
-    mdg->addPropertyToType(tm,"long",        "commonj.sdo","Integer");
+    mdg->addPropertyToType(tm,"long",        "commonj.sdo","Int");
 
     mdg->setDefault("myspace","DefaultTest","long", (long)400);
 
-    mdg->addPropertyToType(tm,"longs",        "commonj.sdo","Integer", true);
+    mdg->addPropertyToType(tm,"longs",        "commonj.sdo","Int", true);
 
     mdg->setDefault("myspace","DefaultTest","longs", (long)800);
 
@@ -1567,10 +1568,10 @@
 
     fprintf(f, "Short default is 300: %d\n",test->getShort("short"));
 
-    fprintf(f, "Long default is 400: %d\n",test->getInteger("long"));
+    fprintf(f, "Long default is 400: %d\n",test->getInt("long"));
 
     try {
-    fprintf(f, "Longs default is 800: %d\n" ,test->getInteger("longs[1]"));
+    fprintf(f, "Longs default is 800: %d\n" ,test->getInt("longs[1]"));
     }
     catch (SDOIndexOutOfRangeException ex)
     {
@@ -1654,11 +1655,11 @@
 
     mdg->setDefault(ns1, testName, "short", (short)300);
 
-    mdg->addPropertyToType(tm, "long", propName, "Integer");
+    mdg->addPropertyToType(tm, "long", propName, "Int");
 
     mdg->setDefault(ns1, testName, "long", (long)400);
 
-    mdg->addPropertyToType(tm, "longs", propName, "Integer", true);
+    mdg->addPropertyToType(tm, "longs", propName, "Int", true);
 
     mdg->setDefault(ns1, testName, "longs", (long)800);
 
@@ -1722,10 +1723,10 @@
 
     fprintf(f, "Short default is 300: %d\n",test->getShort("short"));
 
-    fprintf(f, "Long default is 400: %d\n",test->getInteger("long"));
+    fprintf(f, "Long default is 400: %d\n",test->getInt("long"));
 
     try {
-    fprintf(f, "Longs default is 800: %d\n" ,test->getInteger("longs[1]"));
+    fprintf(f, "Longs default is 800: %d\n" ,test->getInt("longs[1]"));
     }
     catch (SDOIndexOutOfRangeException ex)
     {
@@ -1812,10 +1813,10 @@
     short ss = pshort.getShortDefault();
     fprintf(f, "Short default is : %d\n",ss);
 
-    long ll = plong.getIntegerDefault();
-    fprintf(f, "Integer default is : %d\n",ll);
+    long ll = plong.getIntDefault();
+    fprintf(f, "Int default is : %d\n",ll);
     long ll2 = plongs.getLongDefault();
-    fprintf(f, "Integer many default is : %d\n",ll2);
+    fprintf(f, "Int many default is : %d\n",ll2);
 
     int64_t llll = plonglong.getLongDefault();
     fprintf(f, "Long default is : %ld\n",(long)llll);
@@ -1887,8 +1888,8 @@
     mdg->addPropertyToType(tm,"byte",        "commonj.sdo","Byte");
     mdg->addPropertyToType(tm,"character",  "commonj.sdo","Character");
     mdg->addPropertyToType(tm,"short",        "commonj.sdo","Short");
-    mdg->addPropertyToType(tm,"long",        "commonj.sdo","Integer");
-    mdg->addPropertyToType(tm,"longs",        "commonj.sdo","Integer", true);
+    mdg->addPropertyToType(tm,"long",        "commonj.sdo","Int");
+    mdg->addPropertyToType(tm,"longs",        "commonj.sdo","Int", true);
     mdg->addPropertyToType(tm,"longlong",   "commonj.sdo","Long");
     mdg->addPropertyToType(tm,"float",        "commonj.sdo","Float");
     mdg->addPropertyToType(tm,"longdouble", "commonj.sdo","Double");
@@ -2009,7 +2010,7 @@
     mdg->addPropertyToType(tm,"byte",        "commonj.sdo","Byte");
     mdg->addPropertyToType(tm,"character",  "commonj.sdo","Character");
     mdg->addPropertyToType(tm,"short",        "commonj.sdo","Short");
-    mdg->addPropertyToType(tm,"long",        "commonj.sdo","Integer");
+    mdg->addPropertyToType(tm,"long",        "commonj.sdo","Int");
     mdg->addPropertyToType(tm,"longlong",   "commonj.sdo","Long");
     mdg->addPropertyToType(tm,"float",        "commonj.sdo","Float");
     mdg->addPropertyToType(tm,"longdouble", "commonj.sdo","Double");
@@ -2091,7 +2092,7 @@
     test->setByte("byte",0);
     test->setCharacter("character",0);
     test->setShort("short",0);
-    test->setInteger("long",0);
+    test->setInt("long",0);
     test->setLong("longlong",0 );
     test->setFloat("float",0);
     test->setDouble("longdouble",0 );
@@ -2163,7 +2164,7 @@
     s->addByte(1/*"byte"*/,0);
     s->addCharacter(2/*"character"*/,0);
     s->addShort(3/*"short"*/,0);
-    s->addInteger(4/*"long"*/,0);
+    s->addInt(4/*"long"*/,0);
     s->addLong(5/*"longlong"*/,0 );
     s->addFloat(6/*"float"*/,0);
     s->addDouble(7/*"longdouble"*/,0 );
@@ -2258,7 +2259,7 @@
     s->addByte(1/*"byte"*/,1);
     s->addCharacter(2/*"character"*/,1);
     s->addShort(3/*"short"*/,1);
-    s->addInteger(4/*"long"*/,1);
+    s->addInt(4/*"long"*/,1);
     s->addLong(5/*"longlong"*/,1 );
     s->addFloat(6/*"float"*/,1.0);
     s->addDouble(7/*"longdouble"*/,1.0 );
@@ -2397,7 +2398,7 @@
 
         const Type& tc = mdg->getType("myspace","Company");
         const Type& ts = mdg->getType("commonj.sdo","String");
-        const Type& ti = mdg->getType("commonj.sdo","Integer");
+        const Type& ti = mdg->getType("commonj.sdo","Int");
         const Type& tf = mdg->getType("commonj.sdo","Float");
         const Type& tm = mdg->getType("myspace","Manager");
 
@@ -2497,7 +2498,7 @@
      *
      *        ----depts[] (Department)
      *          ----name (String)
-     *          ----id   (Integer)
+     *          ----id   (Int)
      *          ----manager (Manager).
      *                ----name(String)
                     ----haircolour(String) from Person
@@ -2521,7 +2522,7 @@
         mdg->addPropertyToType(tm,"byte",        "commonj.sdo","Byte");
         mdg->addPropertyToType(tm,"character",  "commonj.sdo","Character");
         mdg->addPropertyToType(tm,"short",        "commonj.sdo","Short");
-        mdg->addPropertyToType(tm,"long",        "commonj.sdo","Integer");
+        mdg->addPropertyToType(tm,"long",        "commonj.sdo","Int");
         mdg->addPropertyToType(tm,"longlong",   "commonj.sdo","Long");
         mdg->addPropertyToType(tm,"float",        "commonj.sdo","Float");
         mdg->addPropertyToType(tm,"longdouble", "commonj.sdo","Double");
@@ -2595,7 +2596,7 @@
 
         try
         {
-            dep1->setInteger("id", 1);
+            dep1->setInt("id", 1);
             if (!silent)cout << "WRONG read-only Property shouldn't have allowed setting" << endl;
             fclose(f);
             return 0;
@@ -2766,7 +2767,7 @@
         pdg->setFloat("float",90.0);
         pdg->setDate("date",(time_t)200);
 
-        // RHEL 4 has problems processing 64 bit integer constants, so we'll do it the hard way
+        // RHEL 4 has problems processing 64 bit int constants, so we'll do it the hard way
         // This is overkill but gives the option to vary the value a bit.
 
         int64_t largeInt1 = 0xFFFF;
@@ -3202,7 +3203,7 @@
 
     const Type& tc = mdg->getType("myspace","Company");
     const Type& ts = mdg->getType("commonj.sdo","String");
-    const Type& ti = mdg->getType("commonj.sdo","Integer");
+    const Type& ti = mdg->getType("commonj.sdo","Int");
     const Type& tf = mdg->getType("commonj.sdo","Float");
     const Type& tm = mdg->getType("myspace","Manager");
     const Type& td = mdg->getType("myspace","Department");
@@ -3324,7 +3325,7 @@
     const Type& tbool=   mdg->getType("commonj.sdo","Boolean");
     const Type& tbyte=   mdg->getType("commonj.sdo","Byte");
     const Type& tchar=   mdg->getType("commonj.sdo","Character");
-    const Type& tint=    mdg->getType("commonj.sdo","Integer");
+    const Type& tint=    mdg->getType("commonj.sdo","Int");
     const Type& tlong=   mdg->getType("commonj.sdo","Long");
     const Type& tfloat=  mdg->getType("commonj.sdo","Float");
     const Type& tbytes = mdg->getType("commonj.sdo","Bytes");
@@ -3386,7 +3387,7 @@
     emp1->setBoolean("bool",true);
     emp1->setByte("byte",'1');
     emp1->setCharacter("char",'1');
-    emp1->setInteger("int",1);
+    emp1->setInt("int",1);
     emp1->setFloat("float",1.0);
     emp1->setLong("long",1);
     emp1->setDouble("double",1.0);
@@ -3413,7 +3414,7 @@
     emp2->setBoolean("bool",true);
     emp2->setByte("byte",'2');
     emp2->setCharacter("char",'2');
-    emp2->setInteger("int",200);
+    emp2->setInt("int",200);
     emp2->setFloat("float",200.0);
     emp2->setLong("long",200);
     emp2->setDouble("double",200.0);
@@ -3439,7 +3440,7 @@
     emp3->setBoolean("bool",false);
     emp3->setByte("byte",'4');
     emp3->setCharacter("char",'4');
-    emp3->setInteger("int",400);
+    emp3->setInt("int",400);
     emp3->setFloat("float",400.0);
     emp3->setLong("long",400);
     emp3->setDouble("double",400.0);
@@ -3589,7 +3590,7 @@
 
     
     const Type& tstring = mdg->getType("commonj.sdo","String");
-    const Type& tint = mdg->getType("commonj.sdo","Integer");
+    const Type& tint = mdg->getType("commonj.sdo","Int");
     const Type& ts = mdg->getType("myspace","School");
     const Type& tc = mdg->getType("myspace","Class");
     const Type& tch = mdg->getType("myspace","Child");
@@ -3653,12 +3654,12 @@
     kid5->setCString("name", "Snagget Minor");
     kid6->setCString("name", "Van Den Bograt");
 
-    kid1->setInteger("number", 1);
-    kid2->setInteger("number", 2);
-    kid3->setInteger("number", 3);
-    kid4->setInteger("number", 4);
-    kid5->setInteger("number", 5);
-    kid6->setInteger("number", 6);
+    kid1->setInt("number", 1);
+    kid2->setInt("number", 2);
+    kid3->setInt("number", 3);
+    kid4->setInt("number", 4);
+    kid5->setInt("number", 5);
+    kid6->setInt("number", 6);
 
     fprintf(f," School  :%s\n", school->getCString("name"));
 
@@ -4250,7 +4251,7 @@
     mdg->addPropertyToType("myspace","Company","strings","commonj.sdo","String",
         true);
 
-    mdg->addPropertyToType("myspace","Company","integers","commonj.sdo","Integer",
+    mdg->addPropertyToType("myspace","Company","ints","commonj.sdo","Int",
         true);
 
 
@@ -4331,7 +4332,7 @@
         if (!silent)cout << "Normal out of range exception in test" << endl;
     }
 
-    DataObjectList& numl = dor->getList("integers");
+    DataObjectList& numl = dor->getList("ints");
 
     try {
         int xx2 = numl.getLength(0);
@@ -4362,7 +4363,7 @@
 
     
     const Type& tstring  = mdg->getType("commonj.sdo","String");
-    const Type& tint     = mdg->getType("commonj.sdo","Integer");
+    const Type& tint     = mdg->getType("commonj.sdo","Int");
     const Type& tassy    = mdg->getType("myspace","Assembly");
     const Type& tsubassy =  mdg->getType("myspace","SubAssembly");
     const Type& tpart    = mdg->getType("myspace","Part");
@@ -4397,27 +4398,27 @@
 
 
     assy1->setCString("name","MicroFrame");
-    assy1->setInteger("number",32768);
+    assy1->setInt("number",32768);
 
     subassy1->setCString("name","Legs");
     subassy2->setCString("name","Body");
-    subassy1->setInteger("number",1);
-    subassy2->setInteger("number",2);
+    subassy1->setInt("number",1);
+    subassy2->setInt("number",2);
 
     part1->setCString("name","Leg1");
     part2->setCString("name","Leg2");
     part3->setCString("name","Leg3");
-    part1->setInteger("number",10001);
-    part2->setInteger("number",10002);
-    part3->setInteger("number",10003);
+    part1->setInt("number",10001);
+    part2->setInt("number",10002);
+    part3->setInt("number",10003);
 
 
     part4->setCString("name","MainStrut");
     part5->setCString("name","Brace1");
     part6->setCString("name","Brace2");
-    part4->setInteger("number",20001);
-    part5->setInteger("number",20002);
-    part6->setInteger("number",20003);
+    part4->setInt("number",20001);
+    part5->setInt("number",20002);
+    part6->setInt("number",20003);
 
     // assy2 - shallow equal to assy, but not deep equal
 
@@ -4436,27 +4437,27 @@
 
 
     assy2->setCString("name","MicroFrame");
-    assy2->setInteger("number",32768);
+    assy2->setInt("number",32768);
 
     subassy3->setCString("name","Legs");
     subassy4->setCString("name","Body");
-    subassy3->setInteger("number",1);
-    subassy4->setInteger("number",2);
+    subassy3->setInt("number",1);
+    subassy4->setInt("number",2);
 
     part7->setCString("name","Leg1");
     part8->setCString("name","Leg2");
     part9->setCString("name","Leg3");
-    part7->setInteger("number",10001);
-    part8->setInteger("number",10002);
-    part9->setInteger("number",10003);
+    part7->setInt("number",10001);
+    part8->setInt("number",10002);
+    part9->setInt("number",10003);
 
 
     part10->setCString("name","MainStrut");
     part11->setCString("name","Brace1");
     part12->setCString("name","OddBrace2");
-    part10->setInteger("number",20001);
-    part11->setInteger("number",20002);
-    part12->setInteger("number",20003);
+    part10->setInt("number",20001);
+    part11->setInt("number",20002);
+    part12->setInt("number",20003);
 
     if (!EqualityHelper::equalShallow(assy1, assy2))
     {
@@ -4516,7 +4517,7 @@
         return 0;
     }
     // now make them not shallow equal
-    assy2->setInteger("number",32767);
+    assy2->setInt("number",32767);
 
     if (EqualityHelper::equalShallow(assy1, assy2))
     {
@@ -4546,7 +4547,7 @@
 
     
     const Type& tstring  = mdg->getType("commonj.sdo","String");
-    const Type& tint     = mdg->getType("commonj.sdo","Integer");
+    const Type& tint     = mdg->getType("commonj.sdo","Int");
     const Type& tassy    = mdg->getType("myspace","Assembly");
     const Type& tsubassy =  mdg->getType("myspace","SubAssembly");
     const Type& tpart    = mdg->getType("myspace","Part");
@@ -4581,27 +4582,27 @@
 
 
     assy1->setCString("name","MicroFrame");
-    assy1->setInteger("number",32768);
+    assy1->setInt("number",32768);
 
     subassy1->setCString("name","Legs");
     subassy2->setCString("name","Body");
-    subassy1->setInteger("number",1);
-    subassy2->setInteger("number",2);
+    subassy1->setInt("number",1);
+    subassy2->setInt("number",2);
 
     part1->setCString("name","Leg1");
     part2->setCString("name","Leg2");
     part3->setCString("name","Leg3");
-    part1->setInteger("number",10001);
-    part2->setInteger("number",10002);
-    part3->setInteger("number",10003);
+    part1->setInt("number",10001);
+    part2->setInt("number",10002);
+    part3->setInt("number",10003);
 
 
     part4->setCString("name","MainStrut");
     part5->setCString("name","Brace1");
     part6->setCString("name","Brace2");
-    part4->setInteger("number",20001);
-    part5->setInteger("number",20002);
-    part6->setInteger("number",20003);
+    part4->setInt("number",20001);
+    part5->setInt("number",20002);
+    part6->setInt("number",20003);
 
     // first lets shallow copy assy1:
 
@@ -4612,7 +4613,7 @@
         if (!silent)cout << "COPYHELPER shallow copy failed(1)" << endl;
         return 0;
     }
-    else if (assy2->getInteger("number") != 32768)
+    else if (assy2->getInt("number") != 32768)
     {
         if (!silent)cout << "COPYHELPER shallow copy 1 failed(2)" << endl;
         return 0;
@@ -5729,7 +5730,7 @@
         
 
         // so, we now expect that the openboolean and openstring props will
-        // be of type boolean and String, and the openlist will be a list of integers.
+        // be of type boolean and String, and the openlist will be a list of ints.
         // The dataobjectlist an dataobject will be of the correct OpenType
 
         // we need a test for data objects, and that we are writing out xsi:type
@@ -5773,15 +5774,15 @@
         if (strcmp(emp->getInstanceProperty("openintlist")->getType().getName(),
             "Short"))
         {
-            if (!silent)cout << "OpenLoad failure - IntegerList not Short " <<
+            if (!silent)cout << "OpenLoad failure - IntList not Short " <<
                 emp->getInstanceProperty("openintlist")->getType().getName() << endl;
             return 0;
         }
 
-        if (dl3.getInteger(0) != 45)
+        if (dl3.getInt(0) != 45)
         {
-            if (!silent)cout << "OpenLoad failure - Integer value is" << 
-                dl.getInteger(0) << endl;
+            if (!silent)cout << "OpenLoad failure - Int value is" << 
+                dl.getInt(0) << endl;
             return 0;
         }
 
@@ -5859,7 +5860,7 @@
         
 
         // so, we now expect that the openboolean and openstring props will
-        // be of type boolean and Bytes, and the openlist will be a list of integers.
+        // be of type boolean and Bytes, and the openlist will be a list of ints.
         // The dataobjectlist an dataobject will be of the correct OpenType
 
         // we need a test for data objects, and that we are writing out xsi:type
@@ -5903,15 +5904,15 @@
         if (strcmp(emp->getInstanceProperty("openintlist")->getType().getName(),
             "Short"))
         {
-            if (!silent)cout << "OpenLoadNS failure - IntegerList not Short " <<
+            if (!silent)cout << "OpenLoadNS failure - IntList not Short " <<
                 emp->getInstanceProperty("openintlist")->getType().getName() << endl;
             return 0;
         }
 
-        if (dl3.getInteger(0) != 45)
+        if (dl3.getInt(0) != 45)
         {
-            if (!silent)cout << "OpenLoadNS failure - Integer value is" << 
-                dl.getInteger(0) << endl;
+            if (!silent)cout << "OpenLoadNS failure - Int value is" << 
+                dl.getInt(0) << endl;
             return 0;
         }
 
@@ -5929,7 +5930,7 @@
         
 
         // so, we now expect that the openboolean and openstring props will
-        // be of type boolean and String, and the openlist will be a list of integers.
+        // be of type boolean and String, and the openlist will be a list of ints.
         // The dataobjectlist an dataobject will be of the correct OpenType
 
         // we need a test for data objects, and that we are writing out xsi:type
@@ -5973,15 +5974,15 @@
         if (strcmp(emp2->getInstanceProperty("openintlist")->getType().getName(),
             "OpenDataObject"))
         {
-            if (!silent)cout << "OpenLoadNS2 failure - IntegerList not OpenDataObject " <<
+            if (!silent)cout << "OpenLoadNS2 failure - IntList not OpenDataObject " <<
                 emp2->getInstanceProperty("openintlist")->getType().getName() << endl;
             return 0;
         }
 
         if (atoi(dl32.getDataObject(0)->getSequence()->getCStringValue(0)) != 45)
         {
-            if (!silent)cout << "OpenLoadNS2 failure - Integer value is" << 
-                dl32.getInteger(0) << endl;
+            if (!silent)cout << "OpenLoadNS2 failure - Int value is" << 
+                dl32.getInt(0) << endl;
             return 0;
         }
         return 1;
@@ -6020,7 +6021,7 @@
         
 
         // so, we now expect that the openboolean and openstring props will
-        // be of type boolean and Bytes, and the openlist will be a list of integers.
+        // be of type boolean and Bytes, and the openlist will be a list of ints.
         // The dataobjectlist an dataobject will be of the correct OpenType
 
         // we need a test for data objects, and that we are writing out xsi:type
@@ -6149,7 +6150,7 @@
     /* Now add the properties to the types...*/
    
     const Type& tstring  = mdg->getType("commonj.sdo","String");
-    const Type& tint     = mdg->getType("commonj.sdo","Integer");
+    const Type& tint     = mdg->getType("commonj.sdo","Int");
     const Type& tbool    = mdg->getType("commonj.sdo","Boolean");
     const Type& tcs      = mdg->getType("commonj.sdo","ChangeSummary");
     const Type& tmain    = mdg->getType("NullNS","NullMainType");
@@ -6190,7 +6191,7 @@
     // sub1 has all values set initially
 
     sub1->setCString("name","All Initially set");
-    sub1->setInteger("number",100);
+    sub1->setInt("number",100);
     sub1->setBoolean("bool",false);
 
     // sub2 has no values set at all
@@ -6268,7 +6269,7 @@
     dol[1]->setNull("bool");
 
     dol[2]->setCString("name","NewName");
-    dol[2]->setInteger("number",100);
+    dol[2]->setInt("number",100);
     dol[2]->setBoolean("bool",true);
 
 
@@ -7223,7 +7224,7 @@
                            "commonj.sdo","String", false, false, false);
 
         mdg->addPropertyToType("myspace","Department","ints",
-                           "commonj.sdo","Integer", true, false, false);
+                           "commonj.sdo","Int", true, false, false);
 
 
         mdg->addPropertyToType("myspace","Department","bool",
@@ -7505,7 +7506,7 @@
 
 
         mdg->addPropertyToType("myspace","Root","ints",
-                           "commonj.sdo","Integer", true, false, false);
+                           "commonj.sdo","Int", true, false, false);
 
 
         const Type& tcc = mdg->getType("myspace","Root");
@@ -7559,10 +7560,10 @@
         mdg->addType("myspace","Root");
 
         mdg->addPropertyToType("myspace","Root","ints",
-                           "commonj.sdo","Integer", true, false, false);
+                           "commonj.sdo","Int", true, false, false);
 
         mdg->addPropertyToType("myspace","Root","ints2",
-                           "commonj.sdo","Integer", true, false, false);
+                           "commonj.sdo","Int", true, false, false);
 
 
         const Type& tcc = mdg->getType("myspace","Root");
@@ -7602,7 +7603,7 @@
     
 
         mdg->addPropertyToType("myspace","Root","ints",
-                           "commonj.sdo","Integer", true, false, false);
+                           "commonj.sdo","Int", true, false, false);
 
         mdg->addPropertyToType("myspace","Root","items",
                            "myspace","ListItem", true, false, true);
@@ -7625,7 +7626,7 @@
         }
 
         try {
-            int inty = dor->getInteger("ints[1]");
+            int inty = dor->getInt("ints[1]");
             return 0;
         }
         catch (SDOIndexOutOfRangeException e)
@@ -7651,7 +7652,7 @@
         dl.append((long)100);
 
         try {
-            int inty2 = dor->getInteger("ints[2]");
+            int inty2 = dor->getInt("ints[2]");
             return 0;
         }
         catch (SDOIndexOutOfRangeException e)
@@ -7670,8 +7671,8 @@
         }
 
         try {
-            int inty2 = dor->getInteger("ints[1]");
-            //cout << "Integer is " << inty2 << endl;
+            int inty2 = dor->getInt("ints[1]");
+            //cout << "Int is " << inty2 << endl;
             return 1;
         }
         catch (SDOIndexOutOfRangeException e)
@@ -8034,7 +8035,7 @@
         mdg->addType("myspace","ListItem");
 
         mdg->addPropertyToType("myspace","Root","ints",
-                           "commonj.sdo","Integer", true, false, false);
+                           "commonj.sdo","Int", true, false, false);
 
         mdg->addPropertyToType("myspace","Root","items",
                            "myspace","ListItem", true, false, true);
@@ -8250,13 +8251,13 @@
                            "test","Unique", true, false, true);
 
         mdg->addPropertyToType("test","Duplicate","id",
-                           "commonj.sdo","Integer", false, false, false);
+                           "commonj.sdo","Int", false, false, false);
  
         mdg->addPropertyToType("nottest","Duplicate","id",
-                           "commonj.sdo","Integer", false, false, false);
+                           "commonj.sdo","Int", false, false, false);
  
         mdg->addPropertyToType("test","Unique","id",
-                           "commonj.sdo","Integer", false, false, false);
+                           "commonj.sdo","Int", false, false, false);
 
         mdg->addPropertyToType("test","Duplicate","ob",
                            "test","Object", false, false, true);
@@ -8276,17 +8277,17 @@
         DataObjectPtr rooty = mdg->create(troot);
 
         DataObjectPtr dup1 = mdg->create(tdup1);
-        dup1->setInteger("id",1);
+        dup1->setInt("id",1);
         DataObjectPtr dup2 = mdg->create(tdup1);
-        dup2->setInteger("id",2);
+        dup2->setInt("id",2);
         DataObjectPtr dup3 = mdg->create(tdup2);
-        dup3->setInteger("id",3);
+        dup3->setInt("id",3);
         DataObjectPtr dup4 = mdg->create(tdup2);
-        dup4->setInteger("id",4);
+        dup4->setInt("id",4);
         DataObjectPtr uni1 = mdg->create(tuniq);
-        uni1->setInteger("id",5);
+        uni1->setInt("id",5);
         DataObjectPtr uni2 = mdg->create(tuniq);
-        uni2->setInteger("id",6);
+        uni2->setInt("id",6);
 
         DataObjectPtr ob1 = mdg->create(tob);
         dup1->setDataObject("ob",ob1);

Modified: incubator/tuscany/cpp/sdo/runtime/core/test/sdotest2.cpp
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sdo/runtime/core/test/sdotest2.cpp?rev=569777&r1=569776&r2=569777&view=diff
==============================================================================
--- incubator/tuscany/cpp/sdo/runtime/core/test/setnull.txt (original)
+++ incubator/tuscany/cpp/sdo/runtime/core/test/setnull.txt Sun Aug 26 01:44:46 2007
@@ -14,7 +14,7 @@
 ===== Old Property Values Begin
 Property name of type String:All Initially set
 
-Property number of type Integer:100
+Property number of type Int:100
 
 Property bool of type Boolean:0
 
@@ -34,7 +34,7 @@
 ===== Old Property Values Begin
 Property name(ISNULL) of type String:
 
-Property number(ISNULL) of type Integer:0
+Property number(ISNULL) of type Int:0
 
 Property bool(ISNULL) of type Boolean:0
 

Modified: incubator/tuscany/cpp/sdo/runtime/core/test/showdefault1.txt
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sdo/runtime/core/test/showdefault1.txt?rev=569777&r1=569776&r2=569777&view=diff
==============================================================================
--- incubator/tuscany/cpp/sdo/runtime/core/test/showdefault1.txt (original)
+++ incubator/tuscany/cpp/sdo/runtime/core/test/showdefault1.txt Sun Aug 26 01:44:46 2007
@@ -5,8 +5,8 @@
 Character default is : 0
 Character default as a string is 0
 Short default is : 0
-Integer default is : 0
-Integer many default is : 0
+Int default is : 0
+Int many default is : 0
 Long default is : 0
 Float default is : 0.000
 Double default is : 0.000

Modified: incubator/tuscany/cpp/sdo/runtime/core/test/showdefault2.txt
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sdo/runtime/core/test/showdefault2.txt?rev=569777&r1=569776&r2=569777&view=diff
==============================================================================
--- incubator/tuscany/cpp/sdo/runtime/core/test/showdefault2.txt (original)
+++ incubator/tuscany/cpp/sdo/runtime/core/test/showdefault2.txt Sun Aug 26 01:44:46 2007
@@ -5,8 +5,8 @@
 Character default is : 101
 Character default as a string is 101
 Short default is : 300
-Integer default is : 400
-Integer many default is : 800
+Int default is : 400
+Int many default is : 800
 Long default is : 500
 Float default is : 600.000
 Double default is : 700.000

Modified: incubator/tuscany/cpp/sdo/runtime/core/test/stock_wsdl.txt
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sdo/runtime/core/test/stock_wsdl.txt?rev=569777&r1=569776&r2=569777&view=diff
==============================================================================
--- incubator/tuscany/cpp/sdo/runtime/core/test/stock_wsdl.txt (original)
+++ incubator/tuscany/cpp/sdo/runtime/core/test/stock_wsdl.txt Sun Aug 26 01:44:46 2007
@@ -1,6 +1,4 @@
 ***** TYPES BEFORE RESOLVE **********************************
-Type:commonj.sdo#BigDecimal
-Type:commonj.sdo#BigInteger
 Type:commonj.sdo#Boolean
 Type:commonj.sdo#Byte
 Type:commonj.sdo#Bytes
@@ -8,8 +6,10 @@
 Type:commonj.sdo#Character
 Type:commonj.sdo#DataObject
 Type:commonj.sdo#Date
+Type:commonj.sdo#Decimal
 Type:commonj.sdo#Double
 Type:commonj.sdo#Float
+Type:commonj.sdo#Int
 Type:commonj.sdo#Integer
 Type:commonj.sdo#Long
 Type:commonj.sdo#OpenDataObject

Modified: incubator/tuscany/cpp/sdo/runtime/core/test/stock_xml.txt
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sdo/runtime/core/test/stock_xml.txt?rev=569777&r1=569776&r2=569777&view=diff
==============================================================================
--- incubator/tuscany/cpp/sdo/runtime/core/test/stock_xml.txt (original)
+++ incubator/tuscany/cpp/sdo/runtime/core/test/stock_xml.txt Sun Aug 26 01:44:46 2007
@@ -1,6 +1,4 @@
 ***** TYPES AFTER RESOLVE*********************************
-Type:commonj.sdo#BigDecimal
-Type:commonj.sdo#BigInteger
 Type:commonj.sdo#Boolean
 Type:commonj.sdo#Byte
 Type:commonj.sdo#Bytes
@@ -8,8 +6,10 @@
 Type:commonj.sdo#Character
 Type:commonj.sdo#DataObject
 Type:commonj.sdo#Date
+Type:commonj.sdo#Decimal
 Type:commonj.sdo#Double
 Type:commonj.sdo#Float
+Type:commonj.sdo#Int
 Type:commonj.sdo#Integer
 Type:commonj.sdo#Long
 Type:commonj.sdo#OpenDataObject

Modified: incubator/tuscany/cpp/sdo/runtime/core/test/teststyles.txt
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sdo/runtime/core/test/teststyles.txt?rev=569777&r1=569776&r2=569777&view=diff
==============================================================================
--- incubator/tuscany/cpp/sdo/runtime/core/test/teststyles.txt (original)
+++ incubator/tuscany/cpp/sdo/runtime/core/test/teststyles.txt Sun Aug 26 01:44:46 2007
@@ -1,6 +1,4 @@
 *****STYLE Style1.xsd
-Type: commonj.sdo#BigDecimal
-Type: commonj.sdo#BigInteger
 Type: commonj.sdo#Boolean
 Type: commonj.sdo#Byte
 Type: commonj.sdo#Bytes
@@ -8,8 +6,10 @@
 Type: commonj.sdo#Character
 Type: commonj.sdo#DataObject
 Type: commonj.sdo#Date
+Type: commonj.sdo#Decimal
 Type: commonj.sdo#Double
 Type: commonj.sdo#Float
+Type: commonj.sdo#Int
 Type: commonj.sdo#Integer
 Type: commonj.sdo#Long
 Type: commonj.sdo#OpenDataObject
@@ -30,8 +30,6 @@
 Root is:libraryNS#library
 Root is:libraryNS#library
 *****STYLE Style2.xsd
-Type: commonj.sdo#BigDecimal
-Type: commonj.sdo#BigInteger
 Type: commonj.sdo#Boolean
 Type: commonj.sdo#Byte
 Type: commonj.sdo#Bytes
@@ -39,8 +37,10 @@
 Type: commonj.sdo#Character
 Type: commonj.sdo#DataObject
 Type: commonj.sdo#Date
+Type: commonj.sdo#Decimal
 Type: commonj.sdo#Double
 Type: commonj.sdo#Float
+Type: commonj.sdo#Int
 Type: commonj.sdo#Integer
 Type: commonj.sdo#Long
 Type: commonj.sdo#OpenDataObject
@@ -61,8 +61,6 @@
 Root is:libraryNS#library
 Root is:libraryNS#library
 *****STYLE Style3.xsd
-Type: commonj.sdo#BigDecimal
-Type: commonj.sdo#BigInteger
 Type: commonj.sdo#Boolean
 Type: commonj.sdo#Byte
 Type: commonj.sdo#Bytes
@@ -70,8 +68,10 @@
 Type: commonj.sdo#Character
 Type: commonj.sdo#DataObject
 Type: commonj.sdo#Date
+Type: commonj.sdo#Decimal
 Type: commonj.sdo#Double
 Type: commonj.sdo#Float
+Type: commonj.sdo#Int
 Type: commonj.sdo#Integer
 Type: commonj.sdo#Long
 Type: commonj.sdo#OpenDataObject

Modified: incubator/tuscany/cpp/sdo/runtime/core/test/travel.txt
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sdo/runtime/core/test/travel.txt?rev=569777&r1=569776&r2=569777&view=diff
==============================================================================
--- incubator/tuscany/cpp/sdo/runtime/core/test/travel.txt (original)
+++ incubator/tuscany/cpp/sdo/runtime/core/test/travel.txt Sun Aug 26 01:44:46 2007
@@ -8,8 +8,6 @@
 TYPE:#Person
 TYPE:#Room
 TYPE:#RootType
-TYPE:commonj.sdo#BigDecimal
-TYPE:commonj.sdo#BigInteger
 TYPE:commonj.sdo#Boolean
 TYPE:commonj.sdo#Byte
 TYPE:commonj.sdo#Bytes
@@ -17,8 +15,10 @@
 TYPE:commonj.sdo#Character
 TYPE:commonj.sdo#DataObject
 TYPE:commonj.sdo#Date
+TYPE:commonj.sdo#Decimal
 TYPE:commonj.sdo#Double
 TYPE:commonj.sdo#Float
+TYPE:commonj.sdo#Int
 TYPE:commonj.sdo#Integer
 TYPE:commonj.sdo#Long
 TYPE:commonj.sdo#OpenDataObject

Modified: incubator/tuscany/cpp/sdo/runtime/core/test/utils.cpp
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sdo/runtime/core/test/utils.cpp?rev=569777&r1=569776&r2=569777&view=diff
==============================================================================
--- incubator/tuscany/cpp/sdo/runtime/core/test/utils.cpp (original)
+++ incubator/tuscany/cpp/sdo/runtime/core/test/utils.cpp Sun Aug 26 01:44:46 2007
@@ -72,7 +72,7 @@
                     fprintf(f,"Character:%d\n",sl[j].getCharacterValue());
                 break;
                 case Type::IntType: 
-                    fprintf(f,"Integer:%d\n",sl[j].getIntegerValue());
+                    fprintf(f,"Int:%d\n",sl[j].getIntValue());
                 break;
                 case Type::ShortType:
                     fprintf(f,"Short:%d\n",sl[j].getShortValue());
@@ -84,7 +84,7 @@
                     fprintf(f,"Float:%.3f\n",sl[j].getFloatValue());
                 break;
                 case Type::LongType:
-                    fprintf(f,"Long:%ld\n",sl[j].getIntegerValue());
+                    fprintf(f,"Long:%ld\n",sl[j].getIntValue());
                 break;
                 case Type::DateType:
                     fprintf(f,"Date:%d\n",sl[j].getDateValue().getTime());
@@ -168,7 +168,7 @@
             fprintf(f,"character:%d\n",dp->getCharacter(p));
         break;
         case Type::IntType: 
-            fprintf(f,"integer:%d\n",dp->getInteger(p));
+            fprintf(f,"int:%d\n",dp->getInt(p));
         break;
         case Type::ShortType:
             fprintf(f,"short:%d\n",dp->getShort(p));
@@ -180,7 +180,7 @@
             fprintf(f,"float:%.3f\n", dp->getFloat(p));
         break;
         case Type::LongType:
-            fprintf(f,"long:%ld\n",dp->getInteger(p));
+            fprintf(f,"long:%ld\n",dp->getInt(p));
         break;
         case Type::DateType:
             fprintf(f,"date:%d\n",dp->getDate(p).getTime());
@@ -194,7 +194,6 @@
         case Type::BytesType:
             fprintf(f,"bytes:%s\n",dp->getCString(p));
         break;
-        case Type::OpenDataObjectType:
         case Type::DataObjectType:
         {
             fprintf(f,"dataObject\n" );
@@ -244,7 +243,7 @@
             fprintf(f,"character[%d]=%d\n",i,dobl.getCharacter(i));
         break;
         case Type::IntType: 
-            fprintf(f,"integer[%d]=%d\n",i,dobl.getInteger(i));
+            fprintf(f,"int[%d]=%d\n",i,dobl.getInt(i));
         break;
         case Type::ShortType:
             fprintf(f,"short[%d]=%d",i, dobl.getShort(i));
@@ -256,7 +255,7 @@
             fprintf(f,"float[%d]=%.3f\n",i,dobl.getFloat(i));
         break;
         case Type::LongType:
-            fprintf(f,"long[%d]=%ld\n",i,dobl.getInteger(i));
+            fprintf(f,"long[%d]=%ld\n",i,dobl.getInt(i));
         break;
         case Type::DateType:
             fprintf(f,"date[%d]=%d\n",i,dobl.getDate(i).getTime());
@@ -270,7 +269,6 @@
         case Type::BytesType:
             fprintf(f,"bytes[%d]=%s\n",i,dobl.getCString(i));
         break;
-        case Type::OpenDataObjectType:
         case Type::DataObjectType:
         {
             fprintf(f,"dataObject[%d]=\n",i);



---------------------------------------------------------------------
To unsubscribe, e-mail: tuscany-commits-unsubscribe@ws.apache.org
For additional commands, e-mail: tuscany-commits-help@ws.apache.org
--- incubator/tuscany/cpp/sdo/runtime/core/test/sdotest2.cpp (original)
+++ incubator/tuscany/cpp/sdo/runtime/core/test/sdotest2.cpp Sun Aug 26 01:44:46 2007
@@ -82,6 +82,10 @@
 
 value = SDOUtils::XSDToSDO("int");
 if (!silent)cout << "XSDToSDO(int)="<< value << endl;
+if (strcmp(value,"Int")) return 0;
+
+value = SDOUtils::XSDToSDO("integer");
+if (!silent)cout << "XSDToSDO(integer)="<< value << endl;
 if (strcmp(value,"Integer")) return 0;
 
 value = SDOUtils::XSDToSDO("notinlist");
@@ -360,7 +364,7 @@
                            "commonj.sdo","String", false, false, true);
    
     f7->addPropertyToType("Namespace","Project","id",
-                           "commonj.sdo","Integer", false, false, false);
+                           "commonj.sdo","Int", false, false, false);
     
     f7->addPropertyToType("Namespace","Project","string",
                            "Namespace","StringHolder", false, false, true);
@@ -373,7 +377,7 @@
                            "Namespace","StringHolder", false, false, true);
 
     f7->addPropertyToType("Namespace","LineItem","itemname",
-                           "commonj.sdo","Integer", false, false, false);
+                           "commonj.sdo","Int", false, false, false);
 
     f7->addPropertyToType("Namespace","LineItem","string",
                            "Namespace","StringHolder", false, false, true);
@@ -1143,8 +1147,8 @@
 
 
         PropertyDefinition* pd = new PropertyDefinition();
-        pd->setName("MyIntegerProperty");
-        pd->setType("commonj.sdo","Integer");
+        pd->setName("MyIntProperty");
+        pd->setType("commonj.sdo","Int");
 
         PropertyDefinition* pd2 = new PropertyDefinition();
         pd2->setName("MyObjectProperty");
@@ -1159,7 +1163,7 @@
         ts->addTypeDefinition(*td2);
 
         // should have an object of type MySmallObject, containing
         // a single integer called MyIntegerProperty, and a list of
         // objects called MyObjectProperty - of type MyOtherObject
 
         xsh->defineTypes(*ts);
@@ -1171,7 +1175,7 @@
         delete pd2;
 
         DataObjectPtr dob = mdg->create("MyNameSpace","MySmallObject");
-        dob->setInteger("MyIntegerProperty",43);
+        dob->setInt("MyIntProperty",43);
 
         dob->createDataObject("MyObjectProperty");
         dob->createDataObject("MyObjectProperty");
@@ -1182,7 +1186,7 @@
             if (!silent) cout << "Define test list size is wrong" << endl;
             return 0;
         }
-        int value = dob->getInteger("MyIntegerProperty");
+        int value = dob->getInt("MyIntProperty");
         if (value != 43)
         {
             if (!silent) cout << "Define test integer value is wrong" << endl;
@@ -1586,7 +1590,7 @@
       // Create three animals based on the preceding types.
       DataObjectPtr baloo = df_both->create("", "bearType");
       baloo->setCString("name", "Mummy bear");
-      baloo->setInteger("weight", 700);
+      baloo->setInt("weight", 700);
 
       DataObjectPtr bagheera = df_both->create("", "pantherType");
       bagheera->setCString("name", "Bagheera");
@@ -1594,7 +1598,7 @@
 
       DataObjectPtr kaa = df_both->create("", "snakeType");
       kaa->setCString("name", "Kaa");
-      kaa->setInteger("length", 25);
+      kaa->setInt("length", 25);
 
       // Create an output document
       XMLHelperPtr xmh_both = HelperProvider::getXMLHelper(df_both);
@@ -1638,7 +1642,7 @@
       // Create three animals based on the preceding types.
       DataObjectPtr baloo = df_2->create("", "bearType");
       baloo->setCString("name", "Mummy bear");
-      baloo->setInteger("weight", 700);
+      baloo->setInt("weight", 700);
 
       DataObjectPtr bagheera = df_2->create("", "pantherType");
       bagheera->setCString("name", "Bagheera");
@@ -1646,7 +1650,7 @@
 
       DataObjectPtr kaa = df_2->create("", "snakeType");
       kaa->setCString("name", "Kaa");
-      kaa->setInteger("length", 25);
+      kaa->setInt("length", 25);
 
       // Create an output document
       XMLHelperPtr xmh_1 = HelperProvider::getXMLHelper(df_1);
@@ -1687,7 +1691,7 @@
       // Create three animals based on the preceding types.
       DataObjectPtr baloo = df_both->create("", "bearType");
       baloo->setCString("name", "Mummy bear");
-      baloo->setInteger("weight", 700);
+      baloo->setInt("weight", 700);
 
       DataObjectPtr bagheera = df_both->create("", "pantherType");
       bagheera->setCString("name", "Bagheera");
@@ -1695,7 +1699,7 @@
 
       DataObjectPtr kaa = df_both->create("", "snakeType");
       kaa->setCString("name", "Kaa");
-      kaa->setInteger("length", 25);
+      kaa->setInt("length", 25);
 
       // Create an output document
       XMLHelperPtr xmh_both = HelperProvider::getXMLHelper(df_both);
@@ -1975,4 +1979,4 @@
         cout << "Exception in xsiTypeAbstract: " << e << endl;
         return 0;
     }
-}
\ No newline at end of file
+}
@@ -1159,7 +1163,7 @@
 
         // should have an object of type MySmallObject, containing
-        // a single integer called MyIntegerProperty, and a list of
+        // a single integer called MyIntProperty, and a list of
         // objects called MyObjectProperty - of type MyOtherObject
 

Modified: incubator/tuscany/cpp/sdo/runtime/core/test/setnull.txt
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sdo/runtime/core/test/setnull.txt?rev=569777&r1=569776&r2=569777&view=diff
==============================================================================